@@ -12,7 +12,7 @@ API_SSL_CERT = os.path.join(os.path.dirname(os.path.abspath(__file__)), "cert/ap
 API_SSL_CONTEXT = httpx.create_ssl_context()
 API_SSL_CONTEXT.load_verify_locations(cafile=API_SSL_CERT)
 API_SSL_CONTEXT.set_ciphers("DEFAULT@SECLEVEL=1")  # the cert uses SHA1-RSA1024bits ciphers so unfortunately we have to lower the security level
-API_SSL_CONTEXT.hostname_checks_common_name=True  # the cert lacks of a subjectaltname
+API_SSL_CONTEXT.hostname_checks_common_name=True  # the cert lacks a subjectaltname
 
 
 APP_PLATFORM = 2  # 1=IOS 2=Android
